<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translation>Первый угол</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second corner</source>
        <translation>Второй угол</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Reference point</source>
        <translation>Точка привязки</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translation>Точка назначения</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translation>&amp;Вытянуть</translation>
    </message>
</context>
</TS>
